@@ -53,6 +53,7 @@ __all__ = [
     'is_union',
     'is_typeddict',
     'is_newtype',
+    'is_optional',
     'uniontypes',
     'literalvalues',
     'NONETYPE',
@@ -76,6 +77,13 @@ try:
 except ImportError:
     pass
 
+UnionType = None  # type: Any
+try:
+    # Since 3.10
+    from types import UnionType  # type: ignore
+except:
+    pass
+
 
 def _issubclass(t1, t2) -> bool:
     """
@@ -115,7 +123,25 @@ def is_union(type_: Type[Any]) -> bool:
     Union
     Optional[A]
     '''
-    return getattr(type_, '__origin__', None) == Union
+
+    # Uniontype is 3.10 defined on 3.10 and None otherwise
+    return getattr(type_, '__origin__', None) == Union or (UnionType and getattr(type_, '__class__', None) == UnionType)
+
+
+def is_optional(type_: Type[Any]) -> bool:
+    '''
+    Optional[int]
+
+    Note that Optional is just a Union, so if is_optional is True then
+    also is_union will be True
+    '''
+    u = is_union(type_)
+    if not u:
+        return False
+    types = uniontypes(type_)
+    if len(types) != 2:
+        return False
+    return NONETYPE in types
 
 
 def is_nonetype(type_: Type[Any]) -> bool:
